@@ -2404,7 +2404,7 @@ def main():
 	parser.add_argument('-reverse_ip', required=True, type=str, default=None, help='reverse_ip set')
 	parser.add_argument('-reverse_port', required=True, type=int, help='reverse_port set')
 	parser.add_argument('-arch', required=True, type=str, help='Target arch architecturet', choices=('mips','mipsel','mips64','mipsel64','armelv5','armelv7','armebv5','armebv7','aarch64','x86','x64','aarch64','android'))
-	parser.add_argument('-res', required=True, type=str,default="reverse_shell_file")
+	parser.add_argument('-res', required=True, type=str,default="reverse_shell_file", choices=('reverse_shell_file', 'reverse_shellcode', 'bind_shell'))
 	parser.add_argument('-passwd', required=False, type=str,default=None)
 	args = parser.parse_args()
 	if (args.res == "reverse_shell_file"):
